@@ -76,7 +76,7 @@ public class JSONToIDConverter extends AbstractJSONConverter {
             ID outgoing = new ID(incoming);
             return outgoing;
         } catch(Exception e) {
-            throw DataExceptionCodes.UNABLE_TO_CHANGE_DATA.create(data.toString(), e);
+            throw DataExceptionCodes.UNABLE_TO_CHANGE_DATA.create(e, data.toString());
         }
     }
 
